@@ -21,7 +21,7 @@ class MarkClient:
     response = requests.post(self.server_url, data=json.dumps(parameters), proxies=self.proxy)
     if self.verbose:
       print "-- Status of the get_server_status request:"
-      print "-- " + str(response.headers)
+      print "-- " + str(response.json())
     response_data = response.json()["result"]
     print "-- Current Active Jobs: " + str(response_data["running"])
     return response_data
@@ -32,7 +32,7 @@ class MarkClient:
     response = requests.post(self.server_url, json=post_data, proxies=self.proxy)
     if self.verbose:
       print "-- Status of the add_evidence request:"
-      print "-- " + str(response.headers)
+      print "-- " + str(response.json())
 
   def find_evidence(self, label, subject):
     print "- Fetching Evidences from to the server"
@@ -40,18 +40,19 @@ class MarkClient:
     response = requests.get(self.server_url, params=parameters, proxies=self.proxy)
     if self.verbose:
       print "-- Status of the find_evidence request:"
-      print "-- " + str(response.headers)
+      print "-- " + str(response.json())
     result_data = response.json()["result"]
     return result_data
 
-  def get_ranked_list(self):
+  def get_ranked_list(self, label):
     print"- Fetching Evidence Ranked List from the server"
-    parameters = {'method': 'findEvidence', 'id': 123, 'params': json.dumps(["aggregation.average"])}
+    result_data = []
+    parameters = {'method': 'findEvidence', 'id': 123, 'params': json.dumps([label])}
     response = requests.get(self.server_url, params=parameters, proxies=self.proxy)
     if self.verbose:
       print "-- Status of the get_ranked_list request:"
-      print "-- " + str(response.headers)
-    result_data = response.json()["result"]
+      print "-- " + str(response.json())
+    result_data = result_data + response.json()["result"]
     # sort the fetched data in descending order (highest score at the top)
     sorted_result_data = sorted(result_data, key=itemgetter('score'), reverse=True)
     return sorted_result_data
@@ -64,11 +65,10 @@ class MarkClient:
     response = requests.get(self.server_url, params=parameters, proxies=self.proxy)
     if self.verbose:
       print "-- Status of the get_unique_subject_count request:"
-      print "-- " + str(response.headers)
+      print "-- " + str(response.json())
     result_data = response.json()["result"]
     return result_data
 
-
   def set_server_url(self, url):
     self.server_url = url
 
